@@ -1,5 +1,4 @@
 use ansi_term::ANSIStrings;
-use clap::ArgMatches;
 use rayon::prelude::*;
 use std::collections::BTreeSet;
 use std::fmt::{self, Debug, Write as FmtWrite};
@@ -10,7 +9,7 @@ use unicode_segmentation::UnicodeSegmentation;
 use unicode_width::UnicodeWidthChar;
 
 use crate::configs::PROMPT_ORDER;
-use crate::context::{Context, Shell};
+use crate::context::{Context, Properties, Shell, Target};
 use crate::formatter::{StringFormatter, VariableHolder};
 use crate::module::Module;
 use crate::module::ALL_MODULES;
@@ -54,8 +53,8 @@ fn test_grapheme_aware_width() {
     assert_eq!(11, "normal text".width_graphemes());
 }
 
-pub fn prompt(args: ArgMatches) {
-    let context = Context::new(args);
+pub fn prompt(args: Properties, target: Target) {
+    let context = Context::new(args, target);
     let stdout = io::stdout();
     let mut handle = stdout.lock();
     write!(handle, "{}", get_prompt(context)).unwrap();
@@ -114,12 +113,13 @@ pub fn get_prompt(context: Context) -> String {
     );
 
     let module_strings = root_module.ansi_strings_for_shell(context.shell, Some(context.width));
-    if config.add_newline {
+    if config.add_newline && context.target != Target::Continuation {
+        // continuation prompts normally do not include newlines, but they can
         writeln!(buf).unwrap();
     }
     write!(buf, "{}", ANSIStrings(&module_strings)).unwrap();
 
-    if context.right {
+    if context.target == Target::Right {
         // right prompts generally do not allow newlines
         buf = buf.replace('\n', "");
     }
@@ -134,8 +134,8 @@ pub fn get_prompt(context: Context) -> String {
     buf
 }
 
-pub fn module(module_name: &str, args: ArgMatches) {
-    let context = Context::new(args);
+pub fn module(module_name: &str, args: Properties) {
+    let context = Context::new(args, Target::Main);
     let module = get_module(module_name, context).unwrap_or_default();
     print!("{}", module);
 }
@@ -144,8 +144,8 @@ pub fn get_module(module_name: &str, context: Context) -> Option<String> {
     modules::handle(module_name, &context).map(|m| m.to_string())
 }
 
-pub fn timings(args: ArgMatches) {
-    let context = Context::new(args);
+pub fn timings(args: Properties) {
+    let context = Context::new(args, Target::Main);
 
     struct ModuleTiming {
         name: String,
@@ -190,8 +190,8 @@ pub fn timings(args: ArgMatches) {
     }
 }
 
-pub fn explain(args: ArgMatches) {
-    let context = Context::new(args);
+pub fn explain(args: Properties) {
+    let context = Context::new(args, Target::Main);
 
     struct ModuleInfo {
         value: String,
@@ -416,22 +416,28 @@ fn load_formatter_and_modules<'a>(context: &'a Context) -> (StringFormatter<'a>,
 
     let lformatter = StringFormatter::new(&config.format);
     let rformatter = StringFormatter::new(&config.right_format);
+    let cformatter = StringFormatter::new(&config.continuation_prompt);
     if lformatter.is_err() {
         log::error!("Error parsing `format`")
     }
     if rformatter.is_err() {
         log::error!("Error parsing `right_format`")
     }
+    if cformatter.is_err() {
+        log::error!("Error parsing `continuation_prompt`")
+    }
 
-    match (lformatter, rformatter) {
-        (Ok(lf), Ok(rf)) => {
+    match (lformatter, rformatter, cformatter) {
+        (Ok(lf), Ok(rf), Ok(cf)) => {
             let mut modules: BTreeSet<String> = BTreeSet::new();
-            modules.extend(lf.get_variables());
-            modules.extend(rf.get_variables());
-            if context.right {
-                (rf, modules)
-            } else {
-                (lf, modules)
+            if context.target != Target::Continuation {
+                modules.extend(lf.get_variables());
+                modules.extend(rf.get_variables());
+            }
+            match context.target {
+                Target::Main => (lf, modules),
+                Target::Right => (rf, modules),
+                Target::Continuation => (cf, modules),
             }
         }
         _ => (StringFormatter::raw(">"), BTreeSet::new()),
@@ -455,10 +461,26 @@ mod test {
             }),
         };
         context.root_config.right_format = "$character".to_string();
-        context.right = true;
+        context.target = Target::Right;
 
         let expected = String::from(">>"); // should strip new lines
         let actual = get_prompt(context);
         assert_eq!(expected, actual);
     }
+
+    #[test]
+    fn continuation_prompt() {
+        let mut context = default_context();
+        context.config = StarshipConfig {
+            config: Some(toml::toml! {
+                continuation_prompt="><>"
+            }),
+        };
+        context.root_config.continuation_prompt = "><>".to_string();
+        context.target = Target::Continuation;
+
+        let expected = String::from("><>");
+        let actual = get_prompt(context);
+        assert_eq!(expected, actual);
+    }
 }
